@@ -1,8 +1,7 @@
 export HOSTNAME=`hostname -f`
 
-export CODENAME=bullseye
+export CODENAME=trixie
 export OUT_BASE=~/publish
-export CD_I_F=${OUT_BASE}/unofficial/non-free/images-including-firmware
 export TRACE=/srv/cdbuilder.debian.org/src/ftp/debian/project/trace/$(hostname).debian.org
 export ARCH_DI_DIR=/srv/cdbuilder.debian.org/src/deb-cd/d-i
 export PUBDIR=/srv/cdbuilder.debian.org/dst/deb-cd
@@ -17,10 +16,5 @@ if [ "$DATE"x = ""x ] ; then
 fi
 
 if [ "$ARCHES"x = ""x ] ; then
-    ARCHES="amd64 i386 multi-arch arm64 armhf armel source ppc64el mipsel mips64el s390x"
+    ARCHES="amd64 arm64 armhf source ppc64el riscv64 s390x"
 fi
-
-if [ "$ARCHES_FIRMWARE"x = ""x ] ; then
-    ARCHES_FIRMWARE="amd64 i386 multi-arch"
-fi
-
